summaryrefslogtreecommitdiffstats
path: root/libk3b/tools
diff options
context:
space:
mode:
Diffstat (limited to 'libk3b/tools')
-rw-r--r--libk3b/tools/k3bbusywidget.cpp6
-rw-r--r--libk3b/tools/k3bbusywidget.h4
-rw-r--r--libk3b/tools/k3bcdparanoialib.h2
-rw-r--r--libk3b/tools/k3bcutcombobox.cpp14
-rw-r--r--libk3b/tools/k3bcutcombobox.h4
-rw-r--r--libk3b/tools/k3bdeviceselectiondialog.cpp2
-rw-r--r--libk3b/tools/k3blistview.cpp44
-rw-r--r--libk3b/tools/k3blistviewitemanimator.cpp2
-rw-r--r--libk3b/tools/k3bmd5job.cpp12
-rw-r--r--libk3b/tools/k3bmsfedit.cpp6
-rw-r--r--libk3b/tools/k3bmsfedit.h2
-rw-r--r--libk3b/tools/k3bmultichoicedialog.cpp2
-rw-r--r--libk3b/tools/k3bprogressdialog.cpp2
-rw-r--r--libk3b/tools/k3bpushbutton.cpp4
-rw-r--r--libk3b/tools/k3brichtextlabel.cpp12
-rw-r--r--libk3b/tools/k3brichtextlabel.h6
-rw-r--r--libk3b/tools/k3bstdguiitems.cpp2
-rw-r--r--libk3b/tools/k3btitlelabel.cpp20
-rw-r--r--libk3b/tools/k3btitlelabel.h8
-rw-r--r--libk3b/tools/k3btoolbox.cpp22
-rw-r--r--libk3b/tools/k3btoolbutton.cpp2
-rw-r--r--libk3b/tools/kcutlabel.cpp8
-rw-r--r--libk3b/tools/kcutlabel.h2
23 files changed, 94 insertions, 94 deletions
diff --git a/libk3b/tools/k3bbusywidget.cpp b/libk3b/tools/k3bbusywidget.cpp
index 34615e3..a5f81e3 100644
--- a/libk3b/tools/k3bbusywidget.cpp
+++ b/libk3b/tools/k3bbusywidget.cpp
@@ -68,13 +68,13 @@ void K3bBusyWidget::animateBusy()
}
-TQSize K3bBusyWidget::sizeHint() const
+TQSize K3bBusyWidget::tqsizeHint() const
{
- return minimumSizeHint();
+ return tqminimumSizeHint();
}
-TQSize K3bBusyWidget::minimumSizeHint() const
+TQSize K3bBusyWidget::tqminimumSizeHint() const
{
return TQSize( 2*frameWidth() + 62, 10 );
}
diff --git a/libk3b/tools/k3bbusywidget.h b/libk3b/tools/k3bbusywidget.h
index bbaddc0..7eb927e 100644
--- a/libk3b/tools/k3bbusywidget.h
+++ b/libk3b/tools/k3bbusywidget.h
@@ -35,8 +35,8 @@ class LIBK3B_EXPORT K3bBusyWidget : public TQFrame
void showBusy( bool b );
- TQSize sizeHint() const;
- TQSize minimumSizeHint() const;
+ TQSize tqsizeHint() const;
+ TQSize tqminimumSizeHint() const;
protected:
void drawContents( TQPainter* p );
diff --git a/libk3b/tools/k3bcdparanoialib.h b/libk3b/tools/k3bcdparanoialib.h
index ff4a09a..bbeb19e 100644
--- a/libk3b/tools/k3bcdparanoialib.h
+++ b/libk3b/tools/k3bcdparanoialib.h
@@ -122,7 +122,7 @@ class LIBK3B_EXPORT K3bCdparanoiaLib
*/
int status() const;
- enum Status {
+ enum tqStatus {
S_OK,
S_ERROR
// to be extended with Jitter and stuff...
diff --git a/libk3b/tools/k3bcutcombobox.cpp b/libk3b/tools/k3bcutcombobox.cpp
index 089e27e..3536c24 100644
--- a/libk3b/tools/k3bcutcombobox.cpp
+++ b/libk3b/tools/k3bcutcombobox.cpp
@@ -45,7 +45,7 @@ K3bCutComboBox::K3bCutComboBox( TQWidget* parent, const char* name )
: KComboBox( parent, name )
{
d = new Private();
- // setSizePolicy( TQSizePolicy::Maximum, sizePolicy().horData(), sizePolicy().hasHeightForWidth() );
+ // tqsetSizePolicy( TQSizePolicy::Maximum, sizePolicy().horData(), sizePolicy().hasHeightForWidth() );
}
@@ -70,9 +70,9 @@ void K3bCutComboBox::setMethod( int m )
}
-TQSize K3bCutComboBox::sizeHint() const
+TQSize K3bCutComboBox::tqsizeHint() const
{
-// TQSize s(KComboBox::sizeHint());
+// TQSize s(KComboBox::tqsizeHint());
// for( int i = 0; i < count(); i++ ) {
// int w = fontMetrics().width(d->originalItems[i]) +
@@ -81,12 +81,12 @@ TQSize K3bCutComboBox::sizeHint() const
// s.setWidth( w );
// }
- return KComboBox::sizeHint();
+ return KComboBox::tqsizeHint();
}
-TQSize K3bCutComboBox::minimumSizeHint() const
+TQSize K3bCutComboBox::tqminimumSizeHint() const
{
- return KComboBox::minimumSizeHint();
+ return KComboBox::tqminimumSizeHint();
}
@@ -205,7 +205,7 @@ void K3bCutComboBox::resizeEvent( TQResizeEvent* e )
void K3bCutComboBox::cutText()
{
- d->width = TQStyle::visualRect( tqstyle().querySubControlMetrics(TQStyle::CC_ComboBox, this,
+ d->width = TQStyle::tqvisualRect( tqstyle().querySubControlMetrics(TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxEditField), this ).width();
for( int i = 0; i < (int)d->originalItems.count(); ++i ) {
diff --git a/libk3b/tools/k3bcutcombobox.h b/libk3b/tools/k3bcutcombobox.h
index 6fdf18e..7bc8f70 100644
--- a/libk3b/tools/k3bcutcombobox.h
+++ b/libk3b/tools/k3bcutcombobox.h
@@ -54,10 +54,10 @@ class LIBK3B_EXPORT K3bCutComboBox : public KComboBox
void setMethod( int );
/** reimplemeted */
- TQSize sizeHint() const;
+ TQSize tqsizeHint() const;
/** reimplemeted */
- TQSize minimumSizeHint() const;
+ TQSize tqminimumSizeHint() const;
/** reimplemeted */
virtual void setCurrentText( const TQString& );
diff --git a/libk3b/tools/k3bdeviceselectiondialog.cpp b/libk3b/tools/k3bdeviceselectiondialog.cpp
index 0c8a3b3..0c6c3f4 100644
--- a/libk3b/tools/k3bdeviceselectiondialog.cpp
+++ b/libk3b/tools/k3bdeviceselectiondialog.cpp
@@ -22,7 +22,7 @@
#include <k3bdevicemanager.h>
#include <tqcombobox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqstring.h>
#include <tqframe.h>
diff --git a/libk3b/tools/k3blistviewitemanimator.cpp b/libk3b/tools/k3blistviewitemanimator.cpp
index 8bb5f69..eef276e 100644
--- a/libk3b/tools/k3blistviewitemanimator.cpp
+++ b/libk3b/tools/k3blistviewitemanimator.cpp
@@ -80,7 +80,7 @@ void K3bListViewItemAnimator::setItem( TQListViewItem* item, int col )
m_item = item;
m_column = col;
m_pixmap = *item->pixmap(col);
- m_fadeColor = item->listView()->colorGroup().base();
+ m_fadeColor = item->listView()->tqcolorGroup().base();
start();
}
diff --git a/libk3b/tools/k3bmd5job.cpp b/libk3b/tools/k3bmd5job.cpp
index 7c20a05..a04c9a0 100644
--- a/libk3b/tools/k3bmd5job.cpp
+++ b/libk3b/tools/k3bmd5job.cpp
@@ -97,14 +97,14 @@ void K3bMd5Job::start()
}
else if( !d->filename.isEmpty() ) {
if( !TQFile::exists( d->filename ) ) {
- emit infoMessage( i18n("Could not find file %1").arg(d->filename), ERROR );
+ emit infoMessage( i18n("Could not find file %1").tqarg(d->filename), ERROR );
jobFinished(false);
return;
}
d->file.setName( d->filename );
if( !d->file.open( IO_ReadOnly ) ) {
- emit infoMessage( i18n("Could not open file %1").arg(d->filename), ERROR );
+ emit infoMessage( i18n("Could not open file %1").tqarg(d->filename), ERROR );
jobFinished(false);
return;
}
@@ -204,7 +204,7 @@ void K3bMd5Job::slotUpdate()
if( readSize <= 0 ) {
// kdDebug() << "(K3bMd5Job) reached max size of " << d->maxSize << ". Stopping." << endl;
- emit debuggingOutput( "K3bMd5Job", TQString("Reached max read of %1. Stopping after %2 bytes.").arg(d->maxSize).arg(d->readData) );
+ emit debuggingOutput( "K3bMd5Job", TQString("Reached max read of %1. Stopping after %2 bytes.").tqarg(d->maxSize).tqarg(d->readData) );
stopAll();
emit percent( 100 );
jobFinished(true);
@@ -252,13 +252,13 @@ void K3bMd5Job::slotUpdate()
}
if( read < 0 ) {
- emit infoMessage( i18n("Error while reading from file %1").arg(d->filename), ERROR );
+ emit infoMessage( i18n("Error while reading from file %1").tqarg(d->filename), ERROR );
stopAll();
jobFinished(false);
}
else if( read == 0 ) {
// kdDebug() << "(K3bMd5Job) read all data. Total size: " << d->readData << ". Stopping." << endl;
- emit debuggingOutput( "K3bMd5Job", TQString("All data read. Stopping after %1 bytes.").arg(d->readData) );
+ emit debuggingOutput( "K3bMd5Job", TQString("All data read. Stopping after %1 bytes.").tqarg(d->readData) );
stopAll();
emit percent( 100 );
jobFinished(true);
@@ -303,7 +303,7 @@ TQCString K3bMd5Job::base64Digest()
void K3bMd5Job::stop()
{
- emit debuggingOutput( "K3bMd5Job", TQString("Stopped manually after %1 bytes.").arg(d->readData) );
+ emit debuggingOutput( "K3bMd5Job", TQString("Stopped manually after %1 bytes.").tqarg(d->readData) );
stopAll();
jobFinished( true );
}
diff --git a/libk3b/tools/k3bmsfedit.cpp b/libk3b/tools/k3bmsfedit.cpp
index e3d3a70..2266be8 100644
--- a/libk3b/tools/k3bmsfedit.cpp
+++ b/libk3b/tools/k3bmsfedit.cpp
@@ -50,16 +50,16 @@ K3bMsfEdit::~K3bMsfEdit()
{}
-TQSize K3bMsfEdit::sizeHint() const
+TQSize K3bMsfEdit::tqsizeHint() const
{
// more or less copied from TQSpinBox
constPolish();
- TQSize sz = editor()->sizeHint();
+ TQSize sz = editor()->tqsizeHint();
int h = sz.height();
TQFontMetrics fm( font() );
int w = fm.width( "00:00:00" );
int wx = fm.width( ' ' )*2;
- int frame = tqstyle().pixelMetric( TQStyle::PM_SpinBoxFrameWidth );
+ int frame = tqstyle().tqpixelMetric( TQStyle::PM_SpinBoxFrameWidth );
return tqstyle().tqsizeFromContents(TQStyle::CT_SpinBox, this,
TQSize( w + wx + downRect().width() + frame*2,
h + frame*2).
diff --git a/libk3b/tools/k3bmsfedit.h b/libk3b/tools/k3bmsfedit.h
index 347b6ad..d3e75ec 100644
--- a/libk3b/tools/k3bmsfedit.h
+++ b/libk3b/tools/k3bmsfedit.h
@@ -41,7 +41,7 @@ class LIBK3B_EXPORT K3bMsfEdit : public TQSpinBox
K3bMsfEdit( TQWidget* parent = 0, const char* name = 0 );
~K3bMsfEdit();
- TQSize sizeHint() const;
+ TQSize tqsizeHint() const;
void setFrameStyle( int style );
void setLineWidth(int);
diff --git a/libk3b/tools/k3bmultichoicedialog.cpp b/libk3b/tools/k3bmultichoicedialog.cpp
index af73154..01f64cd 100644
--- a/libk3b/tools/k3bmultichoicedialog.cpp
+++ b/libk3b/tools/k3bmultichoicedialog.cpp
@@ -21,7 +21,7 @@
#include <kapplication.h>
#include <kiconloader.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqsignalmapper.h>
#include <tqptrlist.h>
#include <tqlabel.h>
diff --git a/libk3b/tools/k3bprogressdialog.cpp b/libk3b/tools/k3bprogressdialog.cpp
index b0e39a8..fe7b2af 100644
--- a/libk3b/tools/k3bprogressdialog.cpp
+++ b/libk3b/tools/k3bprogressdialog.cpp
@@ -19,7 +19,7 @@
#include <tqlabel.h>
#include <tqpushbutton.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqframe.h>
#include <tqwidgetstack.h>
diff --git a/libk3b/tools/k3bpushbutton.cpp b/libk3b/tools/k3bpushbutton.cpp
index 69c6ed5..a4c58bd 100644
--- a/libk3b/tools/k3bpushbutton.cpp
+++ b/libk3b/tools/k3bpushbutton.cpp
@@ -125,10 +125,10 @@ void K3bPushButton::slotDelayedPopup()
if( isDown() ) {
// popup the menu.
// this has been taken from the TQPushButton code
- if( mapToGlobal( TQPoint( 0, rect().bottom() ) ).y() + popup()->sizeHint().height() <= tqApp->desktop()->height() )
+ if( mapToGlobal( TQPoint( 0, rect().bottom() ) ).y() + popup()->tqsizeHint().height() <= tqApp->desktop()->height() )
popup()->exec( mapToGlobal( rect().bottomLeft() ) );
else
- popup()->exec( mapToGlobal( rect().topLeft() - TQPoint( 0, popup()->sizeHint().height() ) ) );
+ popup()->exec( mapToGlobal( rect().topLeft() - TQPoint( 0, popup()->tqsizeHint().height() ) ) );
setDown( false );
}
}
diff --git a/libk3b/tools/k3brichtextlabel.cpp b/libk3b/tools/k3brichtextlabel.cpp
index 92d5877..02878c2 100644
--- a/libk3b/tools/k3brichtextlabel.cpp
+++ b/libk3b/tools/k3brichtextlabel.cpp
@@ -16,7 +16,7 @@
#include "k3brichtextlabel.h"
#include <tqtooltip.h>
-#include <stylesheet.h>
+#include <tqstylesheet.h>
#include <tqsimplerichtext.h>
#include <kglobalsettings.h>
@@ -38,14 +38,14 @@ static TQString qrichtextify( const TQString& text )
K3bRichTextLabel::K3bRichTextLabel( const TQString &text , TQWidget *parent, const char *name )
: TQLabel ( parent, name ) {
m_defaultWidth = TQMIN(400, KGlobalSettings::desktopGeometry(this).width()*2/5);
- setAlignment( TQt::WordBreak );
+ tqsetAlignment( TQt::WordBreak );
setText(text);
}
K3bRichTextLabel::K3bRichTextLabel( TQWidget *parent, const char *name )
: TQLabel ( parent, name ) {
m_defaultWidth = TQMIN(400, KGlobalSettings::desktopGeometry(this).width()*2/5);
- setAlignment( TQt::WordBreak );
+ tqsetAlignment( TQt::WordBreak );
}
void K3bRichTextLabel::setDefaultWidth(int defaultWidth)
@@ -59,7 +59,7 @@ TQSizePolicy K3bRichTextLabel::sizePolicy() const
return TQSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::Minimum, false);
}
-TQSize K3bRichTextLabel::minimumSizeHint() const
+TQSize K3bRichTextLabel::tqminimumSizeHint() const
{
TQString qt_text = qrichtextify( text() );
int pref_width = 0;
@@ -94,9 +94,9 @@ TQSize K3bRichTextLabel::minimumSizeHint() const
return TQSize(pref_width, rt.height());
}
-TQSize K3bRichTextLabel::sizeHint() const
+TQSize K3bRichTextLabel::tqsizeHint() const
{
- return minimumSizeHint();
+ return tqminimumSizeHint();
}
void K3bRichTextLabel::setText( const TQString &text ) {
diff --git a/libk3b/tools/k3brichtextlabel.h b/libk3b/tools/k3brichtextlabel.h
index d2c7250..cf1bc79 100644
--- a/libk3b/tools/k3brichtextlabel.h
+++ b/libk3b/tools/k3brichtextlabel.h
@@ -21,7 +21,7 @@
#include <k3b_export.h>
/**
- * @short A replacement for TQLabel that supports richtext and proper layout management
+ * @short A replacement for TQLabel that supports richtext and proper tqlayout management
*
* @author Waldo Bastian <bastian@kde.org>
*/
@@ -43,8 +43,8 @@ public:
int defaultWidth() const { return m_defaultWidth; }
void setDefaultWidth(int defaultWidth);
- virtual TQSize minimumSizeHint() const;
- virtual TQSize sizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize tqsizeHint() const;
TQSizePolicy sizePolicy() const;
public slots:
diff --git a/libk3b/tools/k3bstdguiitems.cpp b/libk3b/tools/k3bstdguiitems.cpp
index 3b33a18..c8fee1b 100644
--- a/libk3b/tools/k3bstdguiitems.cpp
+++ b/libk3b/tools/k3bstdguiitems.cpp
@@ -20,7 +20,7 @@
#include <tqwhatsthis.h>
#include <tqcombobox.h>
#include <tqframe.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <klocale.h>
diff --git a/libk3b/tools/k3btitlelabel.cpp b/libk3b/tools/k3btitlelabel.cpp
index 0d4f37b..21476b0 100644
--- a/libk3b/tools/k3btitlelabel.cpp
+++ b/libk3b/tools/k3btitlelabel.cpp
@@ -30,7 +30,7 @@ public:
Private() {
titleLength = subTitleLength = 0;
margin = 2;
- alignment = TQt::AlignLeft;
+ tqalignment = TQt::AlignLeft;
cachedMinimumWidth = 0;
titleBaseLine = 0;
}
@@ -41,7 +41,7 @@ public:
TQString displayTitle;
TQString displaySubTitle;
- int alignment;
+ int tqalignment;
int titleLength;
int subTitleLength;
@@ -71,9 +71,9 @@ public:
neededWidth += m_label->d->displaySubTitleLength + 5;
int startPos = 0;
- if( m_label->d->alignment & TQt::AlignHCenter )
+ if( m_label->d->tqalignment & TQt::AlignHCenter )
startPos = r.left() + ( r.width() - 2*m_label->d->margin - neededWidth ) / 2;
- else if( m_label->d->alignment & TQt::AlignRight )
+ else if( m_label->d->tqalignment & TQt::AlignRight )
startPos = r.right() - m_label->d->margin - neededWidth;
else
startPos = r.left() + m_label->d->margin;
@@ -126,19 +126,19 @@ void K3bTitleLabel::setSubTitle( const TQString& subTitle )
}
-void K3bTitleLabel::setAlignment( int align )
+void K3bTitleLabel::tqsetAlignment( int align )
{
- d->alignment = align;
+ d->tqalignment = align;
update();
}
-TQSize K3bTitleLabel::sizeHint() const
+TQSize K3bTitleLabel::tqsizeHint() const
{
return TQSize( d->titleLength + d->subTitleLength + 2*d->margin, d->titleBaseLine );
}
-TQSize K3bTitleLabel::minimumSizeHint() const
+TQSize K3bTitleLabel::tqminimumSizeHint() const
{
return TQSize( d->cachedMinimumWidth, d->titleBaseLine );
}
@@ -168,9 +168,9 @@ void K3bTitleLabel::drawContents( TQPainter* p )
neededWidth += d->displaySubTitleLength + 5;
int startPos = 0;
- if( d->alignment & TQt::AlignHCenter )
+ if( d->tqalignment & TQt::AlignHCenter )
startPos = r.left() + ( r.width() - 2*d->margin - neededWidth ) / 2;
- else if( d->alignment & TQt::AlignRight )
+ else if( d->tqalignment & TQt::AlignRight )
startPos = r.right() - d->margin - neededWidth;
else
startPos = r.left() + d->margin;
diff --git a/libk3b/tools/k3btitlelabel.h b/libk3b/tools/k3btitlelabel.h
index 5e99e59..b850b12 100644
--- a/libk3b/tools/k3btitlelabel.h
+++ b/libk3b/tools/k3btitlelabel.h
@@ -32,8 +32,8 @@ class LIBK3B_EXPORT K3bTitleLabel : public TQFrame
K3bTitleLabel( TQWidget* parent = 0, const char* name = 0 );
~K3bTitleLabel();
- TQSize sizeHint() const;
- TQSize minimumSizeHint() const;
+ TQSize tqsizeHint() const;
+ TQSize tqminimumSizeHint() const;
public slots:
/**
@@ -47,10 +47,10 @@ class LIBK3B_EXPORT K3bTitleLabel : public TQFrame
/**
* The title label only supports alignments left, hcenter, and right
*
- * Default alignment is left.
+ * Default tqalignment is left.
*/
// FIXME: honor right-to-left languages
- void setAlignment( int align );
+ void tqsetAlignment( int align );
protected:
void resizeEvent( TQResizeEvent* );
diff --git a/libk3b/tools/k3btoolbox.cpp b/libk3b/tools/k3btoolbox.cpp
index 216e681..cf72a3b 100644
--- a/libk3b/tools/k3btoolbox.cpp
+++ b/libk3b/tools/k3btoolbox.cpp
@@ -22,7 +22,7 @@
#include <tqtoolbutton.h>
#include <tqsizepolicy.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqwhatsthis.h>
#include <tqtooltip.h>
#include <tqlabel.h>
@@ -44,7 +44,7 @@ class K3bToolBoxSeparator : public TQWidget
public:
K3bToolBoxSeparator( K3bToolBox* parent );
- TQSize sizeHint() const;
+ TQSize tqsizeHint() const;
protected:
void paintEvent( TQPaintEvent * );
@@ -54,13 +54,13 @@ class K3bToolBoxSeparator : public TQWidget
K3bToolBoxSeparator::K3bToolBoxSeparator( K3bToolBox* parent )
: TQWidget( parent )
{
- setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Minimum ) );
+ tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Minimum ) );
}
-TQSize K3bToolBoxSeparator::sizeHint() const
+TQSize K3bToolBoxSeparator::tqsizeHint() const
{
- int extent = tqstyle().pixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
+ int extent = tqstyle().tqpixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
this );
return TQSize( extent, 0 );
}
@@ -72,7 +72,7 @@ void K3bToolBoxSeparator::paintEvent( TQPaintEvent* )
TQStyle::SFlags flags = TQStyle::Style_Default|TQStyle::Style_Horizontal;
tqstyle().tqdrawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
- colorGroup(), flags );
+ tqcolorGroup(), flags );
}
@@ -81,7 +81,7 @@ K3bToolBoxButton::K3bToolBoxButton( KAction* action, TQWidget* parent )
: TQToolButton( parent ),
m_popupMenu(0)
{
- setSizePolicy( TQSizePolicy(TQSizePolicy::Fixed, sizePolicy().verData()) );
+ tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Fixed, tqsizePolicy().verData()) );
setAutoRaise( true );
setIconSet( action->iconSet() );
@@ -127,7 +127,7 @@ K3bToolBoxButton::K3bToolBoxButton( const TQString& text, const TQString& icon,
: TQToolButton( parent ),
m_popupMenu(0)
{
- setSizePolicy( TQSizePolicy(TQSizePolicy::Fixed, sizePolicy().verData()) );
+ tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Fixed, tqsizePolicy().verData()) );
setAutoRaise( true );
setTextLabel( text );
@@ -171,7 +171,7 @@ void K3bToolBoxButton::resizeEvent( TQResizeEvent* e )
K3bToolBox::K3bToolBox( TQWidget* parent, const char* name )
: TQFrame( parent, name )
{
- setSizePolicy( TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed) );
+ tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed) );
m_mainLayout = new TQGridLayout( this );
m_mainLayout->setMargin( 1 );
@@ -243,7 +243,7 @@ void K3bToolBox::addStretch()
void K3bToolBox::addLabel( const TQString& text )
{
TQLabel* label = new TQLabel( text, this );
- label->setSizePolicy( TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed) );
+ label->tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed) );
addWidget( label );
}
@@ -257,7 +257,7 @@ void K3bToolBox::addWidget( TQWidget* w )
m_mainLayout->addWidget( w, 0, m_mainLayout->numCols()-1 );
- if( w->sizePolicy().horData() == TQSizePolicy::Fixed || w->sizePolicy().horData() == TQSizePolicy::Maximum )
+ if( w->tqsizePolicy().horData() == TQSizePolicy::Fixed || w->tqsizePolicy().horData() == TQSizePolicy::Maximum )
m_mainLayout->setColStretch( m_mainLayout->numCols(), 1 );
else {
m_mainLayout->setColStretch( m_mainLayout->numCols()-1, 1 );
diff --git a/libk3b/tools/k3btoolbutton.cpp b/libk3b/tools/k3btoolbutton.cpp
index 5b80907..8f2a20e 100644
--- a/libk3b/tools/k3btoolbutton.cpp
+++ b/libk3b/tools/k3btoolbutton.cpp
@@ -69,7 +69,7 @@ void K3bToolButton::drawButton( TQPainter* p )
arrowFlags |= TQStyle::Style_Enabled;
tqstyle().tqdrawPrimitive(TQStyle::PE_ArrowDown, p,
- TQRect(width()-7, height()-7, 7, 7), colorGroup(),
+ TQRect(width()-7, height()-7, 7, 7), tqcolorGroup(),
arrowFlags, TQStyleOption() );
}
}
diff --git a/libk3b/tools/kcutlabel.cpp b/libk3b/tools/kcutlabel.cpp
index 1ef08ad..fd806ba 100644
--- a/libk3b/tools/kcutlabel.cpp
+++ b/libk3b/tools/kcutlabel.cpp
@@ -27,7 +27,7 @@ KCutLabel::KCutLabel( const TQString &text , TQWidget *parent, const char *name
: TQLabel ( parent, name ),
m_minChars(1) {
TQSizePolicy myLabelSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed );
- setSizePolicy(myLabelSizePolicy);
+ tqsetSizePolicy(myLabelSizePolicy);
m_fullText = text;
cutTextToLabel();
}
@@ -36,12 +36,12 @@ KCutLabel::KCutLabel( TQWidget *parent, const char *name )
: TQLabel ( parent, name ),
m_minChars(1) {
TQSizePolicy myLabelSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed );
- setSizePolicy(myLabelSizePolicy);
+ tqsetSizePolicy(myLabelSizePolicy);
}
-TQSize KCutLabel::minimumSizeHint() const
+TQSize KCutLabel::tqminimumSizeHint() const
{
- TQSize sh = TQLabel::minimumSizeHint();
+ TQSize sh = TQLabel::tqminimumSizeHint();
if( m_minChars == 0 )
sh.setWidth(-1);
else if( m_minChars < (int)m_fullText.length() )
diff --git a/libk3b/tools/kcutlabel.h b/libk3b/tools/kcutlabel.h
index 86c226e..7b96fe2 100644
--- a/libk3b/tools/kcutlabel.h
+++ b/libk3b/tools/kcutlabel.h
@@ -36,7 +36,7 @@ class LIBK3B_EXPORT KCutLabel : public TQLabel
KCutLabel( TQWidget *parent = 0, const char *name = 0);
KCutLabel( const TQString &text, TQWidget *parent = 0, const char *name = 0 );
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
/**
* \return the full text while text() returns the cut text
diff --git a/libk3b/tools/k3blistview.cpp b/libk3b/tools/k3blistview.cpp
index f59ca38..fb3be4b 100644
--- a/libk3b/tools/k3blistview.cpp
+++ b/libk3b/tools/k3blistview.cpp
@@ -33,7 +33,7 @@
#include <tqevent.h>
#include <tqvalidator.h>
#include <tqfont.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqstyle.h>
#include <tqapplication.h>
#include <tqprogressbar.h>
@@ -272,7 +272,7 @@ void K3bListViewItem::setBackgroundColor( int col, const TQColor& c )
ColumnInfo* info = getColumnInfo( col );
info->backgroundColorSet = true;
info->backgroundColor = c;
- repaint();
+ tqrepaint();
}
@@ -281,7 +281,7 @@ void K3bListViewItem::setForegroundColor( int col, const TQColor& c )
ColumnInfo* info = getColumnInfo( col );
info->foregroundColorSet = true;
info->foregroundColor = c;
- repaint();
+ tqrepaint();
}
@@ -299,7 +299,7 @@ void K3bListViewItem::setProgress( int col, int p )
setDisplayProgressBar( col, true );
if( info->progressValue != p ) {
info->progressValue = p;
- repaint();
+ tqrepaint();
}
}
@@ -309,7 +309,7 @@ void K3bListViewItem::setTotalSteps( int col, int steps )
ColumnInfo* info = getColumnInfo( col );
info->totalProgressSteps = steps;
- repaint();
+ tqrepaint();
}
@@ -318,14 +318,14 @@ void K3bListViewItem::setMarginHorizontal( int col, int margin )
ColumnInfo* info = getColumnInfo( col );
info->margin = margin;
- repaint();
+ tqrepaint();
}
void K3bListViewItem::setMarginVertical( int margin )
{
m_vMargin = margin;
- repaint();
+ tqrepaint();
}
@@ -364,7 +364,7 @@ void K3bListViewItem::paintCell( TQPainter* p, const TQColorGroup& cg, int col,
if( info->backgroundColorSet )
cgh.setColor( TQColorGroup::Base, info->backgroundColor );
// in case this is the selected row has a margin we need to repaint the selection bar
if( isSelected() &&
(col == 0 || listView()->allColumnsShowFocus()) &&
info->margin > 0 ) {
@@ -445,11 +445,11 @@ void K3bListViewItem::paintProgressBar( TQPainter* p, const TQColorGroup& cgh, i
s_dummyProgressBar->setTotalSteps( info->totalProgressSteps );
s_dummyProgressBar->setProgress( info->progressValue );
- // some styles use the widget's geometry
+ // some styles use the widget's tqgeometry
s_dummyProgressBar->setGeometry( r );
- listView()->tqstyle().drawControl(TQStyle::CE_ProgressBarContents, &dbPainter, s_dummyProgressBar, r, cgh, flags );
- listView()->tqstyle().drawControl(TQStyle::CE_ProgressBarLabel, &dbPainter, s_dummyProgressBar, r, cgh, flags );
+ listView()->tqstyle().tqdrawControl(TQStyle::CE_ProgressBarContents, &dbPainter, s_dummyProgressBar, r, cgh, flags );
+ listView()->tqstyle().tqdrawControl(TQStyle::CE_ProgressBarLabel, &dbPainter, s_dummyProgressBar, r, cgh, flags );
// now we really paint the progress in the listview
p->drawPixmap( 0, 0, *doubleBuffer );
@@ -498,7 +498,7 @@ bool K3bCheckListViewItem::isChecked() const
void K3bCheckListViewItem::setChecked( bool checked )
{
m_checked = checked;
- repaint();
+ tqrepaint();
}
@@ -508,7 +508,7 @@ void K3bCheckListViewItem::paintK3bCell( TQPainter* p, const TQColorGroup& cg, i
if( col == 0 ) {
if( m_checked ) {
- TQRect r( 0, marginVertical(), width, /*listView()->tqstyle().pixelMetric( TQStyle::PM_CheckListButtonSize )*/height()-2*marginVertical() );
+ TQRect r( 0, marginVertical(), width, /*listView()->tqstyle().tqpixelMetric( TQStyle::PM_CheckListButtonSize )*/height()-2*marginVertical() );
TQStyle::SFlags flags = TQStyle::Style_Default;
if( listView()->isEnabled() )
@@ -666,7 +666,7 @@ void K3bListView::showEditor( K3bListViewItem* item, int col )
void K3bListView::placeEditor( K3bListViewItem* item, int col )
{
ensureItemVisible( item );
- TQRect r = itemRect( item );
+ TQRect r = tqitemRect( item );
r.setX( contentsToViewport( TQPoint(header()->sectionPos( col ), 0) ).x() );
r.setWidth( header()->sectionSize( col ) - 1 );
@@ -699,7 +699,7 @@ void K3bListView::placeEditor( K3bListViewItem* item, int col )
if( TQWidget* editor = prepareEditor( item, col ) ) {
editor->resize( r.size() );
- // editor->resize( TQSize( r.width(), editor->minimumSizeHint().height() ) );
+ // editor->resize( TQSize( r.width(), editor->tqminimumSizeHint().height() ) );
moveChild( editor, r.x(), r.y() );
}
}
@@ -1142,8 +1142,8 @@ bool K3bListView::eventFilter( TQObject* o, TQEvent* e )
TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(d->msfEditLineEdit) ||
TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(d->spinBoxLineEdit) ||
TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_editorComboBox) ) {
- // make sure we did not lose the focus to one of the edit widgets' children
- if( !tqApp->focusWidget() || TQT_BASE_OBJECT(tqApp->focusWidget()->parentWidget()) != TQT_BASE_OBJECT(o) ) {
+ // make sure we did not lose the focus to one of the edit widgets' tqchildren
+ if( !tqApp->tqfocusWidget() || TQT_BASE_OBJECT(tqApp->tqfocusWidget()->parentWidget()) != TQT_BASE_OBJECT(o) ) {
doRename();
hideEditor();
}
@@ -1170,7 +1170,7 @@ void K3bListView::viewportResizeEvent( TQResizeEvent* e )
TQPixmap bgPix( size );
// FIXME: let the user specify the color
- bgPix.fill( colorGroup().base() );
+ bgPix.fill( tqcolorGroup().base() );
if( bgPix.width() < m_backgroundPixmap.width() ||
bgPix.height() < m_backgroundPixmap.height() ) {
@@ -1227,7 +1227,7 @@ KPixmap K3bListView::createDragPixmap( const TQPtrList<TQListViewItem>& items )
int width = header()->width();
int height = 0;
for( TQPtrListIterator<TQListViewItem> it( items ); *it; ++it ) {
- TQRect r = itemRect( *it );
+ TQRect r = tqitemRect( *it );
if( r.isValid() ) {
height += ( *it )->height();
@@ -1256,13 +1256,13 @@ KPixmap K3bListView::createDragPixmap( const TQPtrList<TQListViewItem>& items )
// FIXME: items on other than the top level have a smaller first column
// the same goes for all items if root is decorated
bool alreadyDrawing = false;
- TQRect r = itemRect( item );
+ TQRect r = tqitemRect( item );
if( r.isValid() ) {
if( items.containsRef( item ) ) {
// paint all columns
int x = 0;
for( int i = 0; i < columns(); ++i ) {
- item->paintCell( &p, colorGroup(), i, columnWidth( i ), columnAlignment( i ) );
+ item->paintCell( &p, tqcolorGroup(), i, columnWidth( i ), columnAlignment( i ) );
p.translate( columnWidth( i ), 0 );
x += columnWidth( i );
}
@@ -1274,7 +1274,7 @@ KPixmap K3bListView::createDragPixmap( const TQPtrList<TQListViewItem>& items )
else if( alreadyDrawing )
p.translate( 0, item->height() );
- if( p.worldMatrix().dy() >= pix.height() )
+ if( p.tqworldMatrix().dy() >= pix.height() )
break;
}
}
@@ -364,7 +364,7 @@ void K3bListViewItem::paintCell( TQPainter* p, const TQColorGroup& cg, int col,
if( info->backgroundColorSet )
cgh.setColor( TQColorGroup::Base, info->backgroundColor );
- // in case this is the selected row has a margin we need to repaint the selection bar
+ // in case this is the selected row has a margin we need to tqrepaint the selection bar
if( isSelected() &&
(col == 0 || listView()->allColumnsShowFocus()) &&